Provides the L2-norm projection of points on a subspace, including both scores and reconstructions.
l2projection(X, loadings)data, in matrix or table form
an orthonormal matrix of loadings vectors
'l2projection' returns a list containing the following components:
the matrix of projected points
the matrix of projected points in terms of the original coordinates (reconstructions)
The scores and reconstructions are calculated by solving a linear program.